==> meta_yt-0.1.7-py3-none-any.whl: meta_yt/langauge.py <==
# Dictionary mapping language codes to language names
from typing import Optional

language_code = {
    "ab"     : "Abkhazian",
    "aa"     : "Afar",
    "af"     : "Afrikaans",
    "sq"     : "Albanian",
    "am"     : "Amharic",
    "ar"     : "Arabic",
    "an"     : "Aragonese",
    "hy"     : "Armenian",
    "as"     : "Assamese",
    "ay"     : "Aymara",
    "az"     : "Azerbaijani",
    "ba"     : "Bashkir",
    "eu"     : "Basque",
    "bn"     : "Bengali (Bangla)",
    "dz"     : "Bhutani",
    "bh"     : "Bihari",
    "bi"     : "Bislama",
    "br"     : "Breton",
    "bg"     : "Bulgarian",
    "my"     : "Burmese",
    "be"     : "Byelorussian (Belarusian)",
    "km"     : "Cambodian",
    "ca"     : "Catalan",
    "zh"     : "Chinese",
    "zh-Hans": "Chinese (Simplified)",
    "zh-Hant": "Chinese (Traditional)",
    "co"     : "Corsican",
    "hr"     : "Croatian",
    "cs"     : "Czech",
    "da"     : "Danish",
    "nl"     : "Dutch",
    "en"     : "English",
    "eo"     : "Esperanto",
    "et"     : "Estonian",
    "fo"     : "Faeroese",
    "fa"     : "Farsi",
    "fj"     : "Fiji",
    "fi"     : "Finnish",
    "fr"     : "French",
    "fy"     : "Frisian",
    "gl"     : "Galician",
    "gd"     : "Gaelic (Scottish)",
    "gv"     : "Gaelic (Manx)",
    "ka"     : "Georgian",
    "de"     : "German",
    "el"     : "Greek",
    "kl"     : "Greenlandic",
    "gn"     : "Guarani",
    "gu"     : "Gujarati",
    "ht"     : "Haitian Creole",
    "ha"     : "Hausa",
    "iw"     : "Hebrew",
    "hi"     : "Hindi",
    "hu"     : "Hungarian",
    "is"     : "Icelandic",
    "io"     : "Ido",
    "in"     : "Indonesian",
    "ia"     : "Interlingua",
    "ie"     : "Interlingue",
    "iu"     : "Inuktitut",
    "ik"     : "Inupiak",
    "ga"     : "Irish",
    "it"     : "Italian",
    "ja"     : "Japanese",
    "jv"     : "Javanese",
    "kn"     : "Kannada",
    "ks"     : "Kashmiri",
    "kk"     : "Kazakh",
    "rw"     : "Kinyarwanda (Ruanda)",
    "ky"     : "Kirghiz",
    "rn"     : "Kirundi (Rundi)",
    "ko"     : "Korean",
    "ku"     : "Kurdish",
    "lo"     : "Laothian",
    "la"     : "Latin",
    "lv"     : "Latvian (Lettish)",
    "li"     : "Limburgish ( Limburger)",
    "ln"     : "Lingala",
    "lt"     : "Lithuanian",
    "mk"     : "Macedonian",
    "mg"     : "Malagasy",
    "ms"     : "Malay",
    "ml"     : "Malayalam",
    "mt"     : "Maltese",
    "mi"     : "Maori",
    "mr"     : "Marathi",
    "mo"     : "Moldavian",
    "mn"     : "Mongolian",
    "na"     : "Nauru",
    "ne"     : "Nepali",
    "no"     : "Norwegian",
    "oc"     : "Occitan",
    "or"     : "Oriya",
    "om"     : "Oromo (Afaan Oromo)",
    "ps"     : "Pashto (Pushto)",
    "pl"     : "Polish",
    "pt"     : "Portuguese",
    "pa"     : "Punjabi",
    "qu"     : "Quechua",
    "rm"     : "Rhaeto-Romance",
    "ro"     : "Romanian",
    "ru"     : "Russian",
    "sm"     : "Samoan",
    "sg"     : "Sangro",
    "sa"     : "Sanskrit",
    "sr"     : "Serbian",
    "sh"     : "Serbo-Croatian",
    "st"     : "Sesotho",
    "tn"     : "Setswana",
    "sn"     : "Shona",
    "ii"     : "Sichuan Yi",
    "sd"     : "Sindhi",
    "si"     : "Sinhalese",
    "ss"     : "Siswati",
    "sk"     : "Slovak",
    "sl"     : "Slovenian",
    "so"     : "Somali",
    "es"     : "Spanish",
    "su"     : "Sundanese",
    "sw"     : "Swahili (Kiswahili)",
    "sv"     : "Swedish",
    "tl"     : "Tagalog",
    "tg"     : "Tajik",
    "ta"     : "Tamil",
    "tt"     : "Tatar",
    "te"     : "Telugu",
    "th"     : "Thai",
    "bo"     : "Tibetan",
    "ti"     : "Tigrinya",
    "to"     : "Tonga",
    "ts"     : "Tsonga",
    "tr"     : "Turkish",
    "tk"     : "Turkmen",
    "tw"     : "Twi",
    "ug"     : "Uighur",
    "uk"     : "Ukrainian",
    "ur"     : "Urdu",
    "uz"     : "Uzbek",
    "vi"     : "Vietnamese",
    "vo"     : "Volapük",
    "wa"     : "Wallon",
    "cy"     : "Welsh",
    "wo"     : "Wolof",
    "xh"     : "Xhosa",
    "ji"     : "Yiddish",
    "yo"     : "Yoruba",
    "zu"     : "Zulu",
}


def get_language(code: str) -> Optional[str]:
    """
    Retrieve the language name based on the provided language code.

    Args:
        code (str): The language code for which the language name is to be retrieved.

    Returns:
        Optional[str]: The language name corresponding to the provided code, or None if not found.
    """
    return language_code.get(code)

==> meta_yt-0.1.8-py3-none-any.whl: meta_yt/langauge.py <==
# Dictionary mapping language codes to language names
from typing import Optional

language_code = {
    "af"     : "Afrikaans",
    "ar"     : "Arabic",
    "az"     : "Azerbaijani",
    "be"     : "Belarusian",
    "bg"     : "Bulgarian",
    "bn"     : "Bengali",
    "bs"     : "Bosnian",
    "ca"     : "Catalan",
    "cs"     : "Czech",
    "da"     : "Danish",
    "de"     : "German",
    "el"     : "Greek",
    "en"     : "English",
    "es"     : "Spanish",
    "et"     : "Estonian",
    "eu"     : "Basque",
    "fa"     : "Persian",
    "fi"     : "Finnish",
    "fr"     : "French",
    "ga"     : "Irish",
    "gl"     : "Galician",
    "gu"     : "Gujarati",
    "he"     : "Hebrew",
    "hi"     : "Hindi",
    "hr"     : "Croatian",
    "hu"     : "Hungarian",
    "hy"     : "Armenian",
    "id"     : "Indonesian",
    "is"     : "Icelandic",
    "it"     : "Italian",
    "ja"     : "Japanese",
    "ka"     : "Georgian",
    "kk"     : "Kazakh",
    "km"     : "Khmer",
    "kn"     : "Kannada",
    "ko"     : "Korean",
    "ky"     : "Kyrgyz",
    "lo"     : "Lao",
    "lt"     : "Lithuanian",
    "lv"     : "Latvian",
    "mk"     : "Macedonian",
    "ml"     : "Malayalam",
    "mn"     : "Mongolian",
    "mr"     : "Marathi",
    "ms"     : "Malay",
    "my"     : "Burmese",
    "ne"     : "Nepali",
    "nl"     : "Dutch",
    "no"     : "Norwegian",
    "pa"     : "Punjabi",
    "pl"     : "Polish",
    "pt"     : "Portuguese",
    "ro"     : "Romanian",
    "ru"     : "Russian",
    "si"     : "Sinhala",
    "sk"     : "Slovak",
    "sl"     : "Slovenian",
    "sq"     : "Albanian",
    "sr"     : "Serbian",
    "sv"     : "Swedish",
    "sw"     : "Swahili",
    "ta"     : "Tamil",
    "te"     : "Telugu",
    "th"     : "Thai",
    "tr"     : "Turkish",
    "uk"     : "Ukrainian",
    "ur"     : "Urdu",
    "uz"     : "Uzbek",
    "vi"     : "Vietnamese",
    "zh-Hans": "Chinese (Simplified)",
    "zh-Hant": "Chinese (Traditional)",
    "zu"     : "Zulu"
}


def get_language(code: str) -> Optional[str]:
    """
    Retrieve the language name based on the provided language code.

    Args:
        code (str): The language code for which the language name is to be retrieved.

    Returns:
        Optional[str]: The language name corresponding to the provided code, or None if not found.
    """
    return language_code.get(code)
